==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/TagImportPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class TagImportPolicyFluentImpl<A extends io.fabric8.openshift.api.model.TagImportPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.TagImportPolicyFluent<A>{
  public TagImportPolicyFluentImpl() {
  }
  public TagImportPolicyFluentImpl(io.fabric8.openshift.api.model.TagImportPolicy instance) {
    this.withInsecure(instance.getInsecure()); 
    this.withScheduled(instance.getScheduled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean insecure;
  private java.lang.Boolean scheduled;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getInsecure() {
    return this.insecure;
  }
  public A withInsecure(java.lang.Boolean insecure) {
    this.insecure=insecure; return (A) this;
  }
  public java.lang.Boolean hasInsecure() {
    return this.insecure != null;
  }
  public java.lang.Boolean getScheduled() {
    return this.scheduled;
  }
  public A withScheduled(java.lang.Boolean scheduled) {
    this.scheduled=scheduled; return (A) this;
  }
  public java.lang.Boolean hasScheduled() {
    return this.scheduled != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TagImportPolicyFluentImpl that = (TagImportPolicyFluentImpl) o;
    if (insecure != null ? !insecure.equals(that.insecure) :that.insecure != null) return false;
    if (scheduled != null ? !scheduled.equals(that.scheduled) :that.scheduled != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(insecure,  scheduled,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/TagImportPolicyFluentImpl.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class TagImportPolicyFluentImpl<A extends io.fabric8.openshift.api.model.TagImportPolicyFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.TagImportPolicyFluent<A>{
  public TagImportPolicyFluentImpl() {
  }
  public TagImportPolicyFluentImpl(io.fabric8.openshift.api.model.TagImportPolicy instance) {
    this.withInsecure(instance.getInsecure()); 
    this.withScheduled(instance.getScheduled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean insecure;
  private java.lang.Boolean scheduled;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getInsecure() {
    return this.insecure;
  }
  public A withInsecure(java.lang.Boolean insecure) {
    this.insecure=insecure; return (A) this;
  }
  public java.lang.Boolean hasInsecure() {
    return this.insecure != null;
  }
  public java.lang.Boolean getScheduled() {
    return this.scheduled;
  }
  public A withScheduled(java.lang.Boolean scheduled) {
    this.scheduled=scheduled; return (A) this;
  }
  public java.lang.Boolean hasScheduled() {
    return this.scheduled != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    TagImportPolicyFluentImpl that = (TagImportPolicyFluentImpl) o;
    if (insecure != null ? !insecure.equals(that.insecure) :that.insecure != null) return false;
    if (scheduled != null ? !scheduled.equals(that.scheduled) :that.scheduled != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(insecure,  scheduled,  additionalProperties,  super.hashCode());
  }
  
}
